4b09e1ed23
Reused previous flash saving to improve custom telemetry screens, Timers and footer line items now have labels on all boards
bernet.andre@gmail.com2013-03-05 13:49:53 +00:00
ea6820a046
Wrong array size... was too late last night I guess :\ Of interest: That different way of displaying the custom screen items I introduced in r2033 for conveniency happens to save a whopping 92 bytes on stock!! I forgot about stock when doing it, and when I remembered I expected it would be the opposite and I'd get a slap... Might be worth looking if this could be replicated in other places!
bernet.andre@gmail.com2013-03-05 11:12:59 +00:00
82783013fd
arithmetic overflow check improved: - Now it should be more unlikely to prevent arithmetic overflows. Please test. - This change costs about 20 bytes flash - Unfortunately still not bullet proof. A bullet proof check would cost additionally 100bytes flash, is it worth? - To get in dangerous areas, both weight and offset needs to be set very high. Without offset no more overruns should occur.
open.20.fsguruh@xoxy.net2013-02-28 05:37:16 +00:00
48a7090e6e
[all] Timers countdown / minute beep are configurable [stock] Port from a part of Andreas patch relative to timers. Thanks Andreas! It allowed me to implement the configurable beeps for timers at a almost 0 flash cost.
bsongis2013-02-26 16:07:41 +00:00
6fc8ba804c
[all] Timers countdown / minute beep are configurable [stock] Port from a part of Andreas patch relative to timers. Thanks Andreas! It allowed me to implement the configurable beeps for timers at a almost 0 flash cost.
bsongis2013-02-26 16:07:41 +00:00
dcfbd424dd
[X9D] Branch based on r2011 for trying to get mass storage to work... library should be included more or less correctly, need to now connect with the SD card driver (in x9d/usbd_storage_msd.c)
bernet.andre@gmail.com2013-02-25 20:13:14 +00:00
e35cf751de
[9x] BATTGRAPH option added to display the Tx voltage [all] AdjustGVARs feature reworked (now 4 modes) [!ARM] PlayTrack can now play GVARs
bsongis2013-02-25 18:48:11 +00:00
38bcc1f29f
[X9D] SPORT driver draft, only feeds the frsky packed decoder for displaying good old telemetry for now
bernet.andre@gmail.com2013-02-24 17:19:42 +00:00
d9d52762ae
[voice] ONm correctly reset on model change [X9D] Default bitmap on main view when none selected / no SD
bernet.andre@gmail.com2013-02-22 15:44:52 +00:00
b7a37c4e8a
[all] Stupid bug in calcRESXto100
bsongis2013-02-21 21:14:14 +00:00
21a5238ca9
[all] Mixer problem with switches
bsongis2013-02-21 20:41:48 +00:00
3824939030
[all] And switches added to Custom Switches [ARM] No Init of SD after a reboot (not tested) [X9D] Bug when [EXIT] on MODELSEL
bsongis2013-02-21 20:25:40 +00:00
1e3c1d8ce2
Expo EXTENDED function added, SLOW moved to old position, 8 bytes code saved
open.20.fsguruh@xoxy.net2013-02-21 20:17:54 +00:00
8cfde7854b
[X9D] Reboot when changing the model
bsongis2013-02-21 10:51:46 +00:00
4a1ae0eaa4
Issue 203 fixed (Timer minute beep) Issue 204 fixed (Tx Batt spoken) [X9D] It was impossible to avoid a Format on EEPROM Alert [all] Function v1==x modified to v1~=x (needs to be tested) Developers list updated
bsongis2013-02-20 11:17:44 +00:00
35fc938b1e
Safety channel fix This change should avoid setting all output channels to 0 for the first few outputs generated. Also this prevents the throttle triggered timers to start not intended after power up. This occurs when you set throttle timers to output channel instead of stick. (By the way, is there any reason, this should be the source at all?) Because reset of safety channels is only moved, this do not cost any additional bytes of flash. However the reinitialisation in evalFunctions() may be missing somewhere? Please comment...
open.20.fsguruh@xoxy.net2013-02-18 22:03:43 +00:00
abb604bf6d
[X9D] Virtual switches in Mixer sources should now work correctly
bsongis2013-02-18 21:45:35 +00:00
8eaefce7b5
[X9D] Shift in Mixer sources
bsongis2013-02-18 20:40:41 +00:00
63e2ae60a5
now does rescaling on 256base instead of 100; removes a lot of division by a shift right 8 Needs testing!!! Volunteer please come in. Benefits of change: -248 bytes code generated used gcc 4.7.2 -huge performance increase. My measurements: simple mix goes down from 2,87msec to 1.93msec middle complex mix goes down from 3,37msec to 2,00msec complex mix (with phase change) goes down from 6,87msec to 4,18msec
open.20.fsguruh@xoxy.net2013-02-18 20:26:16 +00:00